@@ -410,5 +410,5 @@ func formulaNameFor(name string) string {
 	name = strings.ReplaceAll(name, "_", " ")
 	name = strings.ReplaceAll(name, ".", "_")
 	name = strings.ReplaceAll(name, "@", "AT")
-	return strings.ReplaceAll(strings.Title(name), " ", "")
+	return strings.ReplaceAll(strings.Title(name), " ", "") // nolint:staticcheck
 }
